]> sigrok.org Git - libsigrok.git/blobdiff - device.c
demo: Use memset(), might be faster.
[libsigrok.git] / device.c
index 04d463c13e2a9fe34d85a6fe7cdd4095be9ecae8..fea3d60bedfc235f87e59f5d5f6ba958a897892c 100644 (file)
--- a/device.c
+++ b/device.c
@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <glib.h>
 #include <sigrok.h>
+#include <sigrok-internal.h>
 
 extern struct sr_global *global;
 
@@ -30,7 +31,7 @@ void sr_device_scan(void)
        GSList *plugins, *l;
        struct sr_device_plugin *plugin;
 
-       plugins = list_hwplugins();
+       plugins = sr_list_hwplugins();
 
        /*
         * Initialize all plugins first. Since the init() call may involve
@@ -48,7 +49,7 @@ int sr_device_plugin_init(struct sr_device_plugin *plugin)
 {
        int num_devices, num_probes, i;
 
-       g_message("initializing %s plugin", plugin->name);
+       sr_info("initializing %s plugin", plugin->name);
        num_devices = plugin->init(NULL);
        for (i = 0; i < num_devices; i++) {
                num_probes = (int)plugin->get_device_info(i, SR_DI_NUM_PROBES);
@@ -60,12 +61,18 @@ int sr_device_plugin_init(struct sr_device_plugin *plugin)
 
 void sr_device_close_all(void)
 {
+       int ret;
        struct sr_device *device;
 
        while (devices) {
                device = devices->data;
-               if (device->plugin && device->plugin->close)
-                       device->plugin->close(device->plugin_index);
+               if (device->plugin && device->plugin->closedev) {
+                       ret = device->plugin->closedev(device->plugin_index);
+                       if (ret != SR_OK) {
+                               sr_err("dev: %s: could not close device %d",
+                                      __func__, device->plugin_index);
+                       }
+               }
                sr_device_destroy(device);
        }
 }
@@ -85,7 +92,11 @@ struct sr_device *sr_device_new(struct sr_device_plugin *plugin, int plugin_inde
        struct sr_device *device;
        int i;
 
-       device = g_malloc0(sizeof(struct sr_device));
+       if (!(device = g_try_malloc0(sizeof(struct sr_device)))) {
+               sr_err("dev: %s: device malloc failed", __func__);
+               return NULL;
+       }
+
        device->plugin = plugin;
        device->plugin_index = plugin_index;
        devices = g_slist_append(devices, device);
@@ -146,14 +157,20 @@ void sr_device_probe_clear(struct sr_device *device, int probenum)
        }
 }
 
-void sr_device_probe_add(struct sr_device *device, char *name)
+void sr_device_probe_add(struct sr_device *device, const char *name)
 {
        struct sr_probe *p;
        char probename[16];
        int probenum;
 
        probenum = g_slist_length(device->probes) + 1;
-       p = g_malloc0(sizeof(struct sr_probe));
+
+       if (!(p = g_try_malloc0(sizeof(struct sr_probe)))) {
+               sr_err("dev: %s: p malloc failed", __func__);
+               // return SR_ERR_MALLOC;
+               return; /* FIXME: should return int. */
+       }
+
        p->index = probenum;
        p->enabled = TRUE;
        if (name) {
@@ -183,8 +200,9 @@ struct sr_probe *sr_device_probe_find(struct sr_device *device, int probenum)
        return found_probe;
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
-void sr_device_probe_name(struct sr_device *device, int probenum, char *name)
+/* TODO: return SR_ERR if probenum not found */
+void sr_device_probe_name(struct sr_device *device, int probenum,
+                         const char *name)
 {
        struct sr_probe *p;
 
@@ -197,7 +215,7 @@ void sr_device_probe_name(struct sr_device *device, int probenum, char *name)
        p->name = g_strdup(name);
 }
 
/* TODO: return SIGROK_ERR if probenum not found */
 void sr_device_trigger_clear(struct sr_device *device)
 {
        struct sr_probe *p;
@@ -215,8 +233,9 @@ void sr_device_trigger_clear(struct sr_device *device)
        }
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
-void sr_device_trigger_set(struct sr_device *device, int probenum, char *trigger)
+/* TODO: return SR_ERR if probenum not found */
+void sr_device_trigger_set(struct sr_device *device, int probenum,
+                          const char *trigger)
 {
        struct sr_probe *p;
 
@@ -236,7 +255,7 @@ gboolean sr_device_has_hwcap(struct sr_device *device, int hwcap)
        int *capabilities, i;
 
        if (!device || !device->plugin)
-               return;
+               return FALSE;
 
        if ((capabilities = device->plugin->get_capabilities()))
                for (i = 0; capabilities[i]; i++)
@@ -197,7 +215,7 @@ void sr_device_probe_name(struct sr_device *device, int probenum, char *name)
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
+/* TODO: return SR_ERR if probenum not found */
 void sr_device_trigger_clear(struct sr_device *device)
 {